upoints.cities

Package upoints :: Module cities |
[hide private]
[frames] | no frames]

# Module cities

cities - Imports GNU miscfiles cities data files

Classes | [hide private]
| City Class for representing an entry from the GNU miscfiles cities data file
| Cities Class for representing a group of City objects

Variables | [hide private]
| TEMPLATE = ``'``ID : %s\nType : %s\nPopulation :` `...`` GNU miscfiles cities.dat template

Variables Details | [hide private]

  ### TEMPLATE GNU miscfiles cities.dat template Value:
      '''ID          : %s
      Type        : %s
      Population  : %s
      Size        : %s
      Name        : %s
       Country    : %s
       Region     : %s
      Location    : %s
      ...